@@ -1,7 +1,7 @@
-#' Tagloss_LengthObs returns a list with the number of days different kinds of individuals are seen.
-#' @title Return a list with the number of days different kinds of individuals are seen.
+#' Tagloss_LengthObs returns a list with the number of days for different kinds of individuals are seen.
+#' @title Return a list with the number of days for different kinds of individuals are seen.
 #' @author Marc Girondot
-#' @return Return a list with the number of days different kinds of individuals are seen.
+#' @return Return a list with the number of days for different kinds of individuals are seen.
 #' @param data Set of indivuals
 #' @param progressbar Is shown a progressbar?
 #' @description Usefull to summarize data
@@ -17,6 +17,8 @@
 
 Tagloss_LengthObs <- function(data, progressbar=TRUE) {
   
+  class(data) <- "data.frame"
+  
   lv <- levels(data$ID)
   
   if (progressbar) {
